==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/SplineAreaFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineFragmentBaseDescriptionMetadata } from "./SplineFragmentBaseDescriptionMetadata";
import { SplineAreaFragmentDescription } from "./SplineAreaFragmentDescription";
/**
 * @hidden
 */
var SplineAreaFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SplineAreaFragmentDescriptionMetadata, _super);
    function SplineAreaFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SplineAreaFragmentDescriptionMetadata.b = function (a) {
        if (SplineAreaFragmentDescriptionMetadata.a == null) {
            SplineAreaFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SplineAreaFragmentDescriptionMetadata.c(SplineAreaFragmentDescriptionMetadata.a);
        }
        if (a.k(SplineAreaFragmentDescriptionMetadata.a)) {
            return;
        }
        a.ab(SplineAreaFragmentDescriptionMetadata.a);
    };
    SplineAreaFragmentDescriptionMetadata.c = function (a) {
        SplineFragmentBaseDescriptionMetadata.c(a);
    };
    SplineAreaFragmentDescriptionMetadata.d = function (a) {
        SplineAreaFragmentDescriptionMetadata.b(a);
        a.ad("SplineAreaFragment", function () { return new SplineAreaFragmentDescription(); });
        a.ac("SplineAreaFragment", SplineAreaFragmentDescriptionMetadata.a);
    };
    SplineAreaFragmentDescriptionMetadata.$t = markType(SplineAreaFragmentDescriptionMetadata, 'SplineAreaFragmentDescriptionMetadata');
    SplineAreaFragmentDescriptionMetadata.a = null;
    return SplineAreaFragmentDescriptionMetadata;
}(Base));
export { SplineAreaFragmentDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/SplineAreaFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineFragmentBaseDescriptionMetadata } from "./SplineFragmentBaseDescriptionMetadata";
import { SplineAreaFragmentDescription } from "./SplineAreaFragmentDescription";
/**
 * @hidden
 */
var SplineAreaFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SplineAreaFragmentDescriptionMetadata, _super);
    function SplineAreaFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SplineAreaFragmentDescriptionMetadata.b = function (a) {
        if (SplineAreaFragmentDescriptionMetadata.a == null) {
            SplineAreaFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SplineAreaFragmentDescriptionMetadata.c(SplineAreaFragmentDescriptionMetadata.a);
        }
        if (a.k(SplineAreaFragmentDescriptionMetadata.a)) {
            return;
        }
        a.ac(SplineAreaFragmentDescriptionMetadata.a);
    };
    SplineAreaFragmentDescriptionMetadata.c = function (a) {
        SplineFragmentBaseDescriptionMetadata.c(a);
    };
    SplineAreaFragmentDescriptionMetadata.d = function (a) {
        SplineAreaFragmentDescriptionMetadata.b(a);
        a.ae("SplineAreaFragment", function () { return new SplineAreaFragmentDescription(); });
        a.ad("SplineAreaFragment", SplineAreaFragmentDescriptionMetadata.a);
    };
    SplineAreaFragmentDescriptionMetadata.$t = markType(SplineAreaFragmentDescriptionMetadata, 'SplineAreaFragmentDescriptionMetadata');
    SplineAreaFragmentDescriptionMetadata.a = null;
    return SplineAreaFragmentDescriptionMetadata;
}(Base));
export { SplineAreaFragmentDescriptionMetadata };
